######################################################################
## R code of main and supplementary analyses of manuscript "Moisture, density-dependent interactions, and tropical tree diversity"; 
## Authors: Edwin Lebrija-Trejos, Andr?s Hern?ndez and S. Joseph Wright
## Includes seedling survival model fitting routines, diversity analyses and  code to compare BCI and Lutz watershed soil moisture data, 
## evaluate rainfall as metric of water availability, and calculate CI of CNDD effects

## LOAD PACKAGES AND FILES ####
library(nlme)
library(lme4)
library(arm)
library(DHARMa)
library(foreach)
library(doParallel)
library(reshape2)
library(vegan)
library(cocor)
library(lubridate)
library(doBy)

# SET DIRECTORIES

sourcefiles<-'C:/Users/...'# local directory path (not shown)
sourcefiles4R<-'C:/Users/Edwin/Documents/MyDocs_XPS13/Collaborations/WrightJoe&Hellene/For Submission/Nature/Review_materials/Source R files/4th Rev final'

# LOAD DATA generated in this study
# Dynamics data
Data<-read.table(file=paste(sourcefiles4R,"Seedl_SM.csv",sep="/"), sep=",", header=T, as.is = T)
 # First year seedling survival data with neighbor density, moisture predictors and focal species name ('SPECIES'), PLOT, TRAP and YEAR indicators.  
# Each plot has a unique ID. Thus, glmer models below are coded with implicit nesting (i.e., (1|PLOT) + (1|TRAP)). Nesting of plots within traps is shown explicitly in the ms (i.e., (1|TRAP/PLOT)).

# Diversity data
Div.db<-read.table(file=paste(sourcefiles4R,"Div_SM.csv",sep="/"), sep=",", header=T, as.is = T) # Observed Hill diversity (D1 and D2) data for recruits ('Rec') and 1 y-old seedlings ('1Y')

DivDb20<-read.table(file=paste(sourcefiles4R,"Div_overTime.csv",sep="/"), sep=",", header=T, as.is = T)# matrix with diversity estimates for seedling cohorts 0-24 years old (columns) by year (rows) from 1995 to 2019.

# DIVERSITY & SOIL MOISTURE  ####
# ARE RELATIVE CHANGES IN FIRST-YEAR COHORT DIVERSITY CORRELATED WITH SOIL MOISTURE? (Ms FIGURE 1)
# CALCULATE REL CHANGE IN DIVERSITY for observed data
DD.rel <- data.frame(YEAR = Div.db$YEAR, #mYEAR is the year used to analyze survival (the 1st year after recruitment, not the year of recruitment)
                      Dlt.D2 = ((Div.db$D2.1Y - Div.db$D2Rec) / Div.db$D2Rec)*100,
                      Dlt.D1 = ((Div.db$D1.1Y - Div.db$D1Rec) / Div.db$D1Rec)*100)
Div.all <- merge(Div.db, DD.rel)

# D2
# Fit models with homoscedastic (no weights) and heteroscedastic variance structures (power and exponential)
ws.uw <- gls(Dlt.D2 ~ SMw.raw, data= Div.all) # constant variance model
# Models of first year changes in seedling diversity as a function of soil moisture during the wet season use raw gravimetric soil water content expressed as a percent value (SMw.raw). 
# The soil moisture variable used in the seedling survival models is transformed (median centered and standardized by the Inter Quartile Range and is named "SMw"). 
plot(ws.uw) # variance increases with x
ws.w.vp <- gls(Dlt.D2 ~ SMw.raw, data = Div.all, weights = varPower(form=~SMw.raw))
ws.w.ve <- gls(Dlt.D2 ~ SMw.raw, data = Div.all, weights = varExp(form=~SMw.raw))
anova(ws.uw,ws.w.vp,ws.w.ve) # varPower form with lowest AIC (153.1 vs. 156.7 for ws.uw)
summary(ws.w.vp) # Slope (Fig.1)
cor.test(Div.all$SMw.raw, Div.all$Dlt.D2, method = "spearman") # Results in Fig. 1

# D1
# Results in Extended Data Fig (EDF) 2
ws.uw <- gls(Dlt.D1 ~ SMw.raw,  data= Div.all) # constant variance model
plot(ws.uw) # variance increases with x
ws.w.vp <- gls(Dlt.D1 ~ SMw.raw, weights=varPower(form=~SMw.raw), data= Div.all)
ws.w.ve <- gls(Dlt.D1 ~ SMw.raw, weights=varExp(form=~SMw.raw), data= Div.all)
anova(ws.uw,ws.w.vp,ws.w.ve) # varPower form with lowest AIC (146.9 vs 149.1 for ws.uw)
summary(ws.w.vp)  # Slope Extended Data Fig 2
cor.test(Div.all$SMw.raw, Div.all$Dlt.D1, method = "spearman") # correlation in EDF 2

# SEEDLING SURVIVAL ANALYSIS (MODEL FITTING) ####
# How does seedling survival vary with mean soil moisture (SM), species-specific moisture optima (SpMO), & neighbor density (CSD, CLD, HSD and HLD)?

# CHECK FOR NON-LINEAR RESPONSES to density, i.e for square and fourth roots of CSD, HSD, CLD and HLD

# Fit maximal model with UNTRANSFORMED variables (returns Singular fit warning after model update)
SMm1 <- glmer(ALIVE ~ CSD + HSD + CLD + HLD + SMw + CSD:SMw + HSD:SMw + SpMO + SpMO:SMw
                        + (1 + CSD + HSD + CLD + HLD + SMw + CSD:SMw + HSD:SMw|SPECIES)
                        + (1|PLOT) + (1|TRAP) 
                        + (1 + CSD + HSD + CLD + HLD + SpMO|YEAR),
                        control = glmerControl(optCtrl = list(maxfun = 1e+06)),
                        data = Data, family = binomial, verbose = 2, nAGQ = 1) # model fails to converge (try model update or alternative optimizer)

# Update model; restart fit with last set of parameters
ss <- getME(SMm1, c("theta","fixef"))
SMm1u<- update(SMm1, start = ss, control = glmerControl(optCtrl = list(maxfun=1e5))) # singular fit

# Simplify random structure following Barr et al. 2013 (i.e. remove correlations among random terms first).
# Remove correlations among random terms by year because they have the lowest SD estimates (returns singular fit after model update). 
SMwncyT1<- glmer(ALIVE ~ CSD + HSD + CLD + HLD + SMw + CSD:SMw + HSD:SMw + SpMO + SpMO:SMw
                      + (1 + CSD + HSD + CLD + HLD + SMw + CSD:SMw + HSD:SMw|SPECIES)
                      + (1|PLOT) + (1|TRAP) 
                      + (1 + CSD + HSD + CLD + HLD + SpMO||YEAR), # the double bar removes correlations among specified terms
                      control = glmerControl(optCtrl = list(maxfun = 1e+06)),
                      data = Data, family = binomial, verbose = 2, nAGQ = 1) # model fails to converge  

# restart fit with last set of parameters
ss <- getME(SMwncyT1, c("theta","fixef"))
SMwncyT1u <- update(SMwncyT1, start = ss, control = glmerControl(optCtrl = list(maxfun=1e5))) # singular fit

# Remove correlations among random terms by species (model converges without warnings)
SMwncsT1<- glmer(ALIVE ~ CSD + HSD + CLD + HLD + SMw + CSD:SMw + HSD:SMw + SpMO + SpMO:SMw
                       + (1 + CSD + HSD + CLD + HLD + SMw + CSD:SMw + HSD:SMw||SPECIES)
                       + (1|PLOT) + (1|TRAP) 
                       + (1 + CSD + HSD + CLD + HLD + SpMO|YEAR),
                       control = glmerControl(optCtrl = list(maxfun = 1e+06)),
                       data = Data, family = binomial, verbose = 2, nAGQ = 1)

# During analyses of previous ms versions, correlations among species terms were removed one by one, starting with the term with the lowest variance estimate, 
# following with the term with the second lowest variance, and so on. E.g., for removing correlations of HLD among species only, the random term syntax was:  
# ... + (1 + CSD + HSD + CLD + SMw + CSD:SMw + HSD:SMw|SPECIES) + (0+ HLD|SPECIES) + (1|PLOT)... 
# Per variable tested, tens of models with different random structures were fitted using the High performance computing system, "HIVE" of the Faculty of Natural 
# Sciences at the University of Haifa. Different models converged without warnings with different random effect structures. Some models only converged when all 
# correlations among random terms were removed (as shown below). A 'No correlations' model was thus selected as base model for alternative model comparisons.

# Model comparisons
# Fit same reduced model with CSD^1/2 (compare model with same random structure, i.e., no correlations among random terms by species) 
# (model fails to converge, also after restarting model fit with last set of parameters or using alternative optimizer(s))
SMwncsT2 <- glmer(ALIVE ~ CSD.sqrt + HSD + CLD + HLD + SMw + CSD.sqrt:SMw + HSD:SMw + SpMO +SpMO:SMw
                       + (1 + CSD.sqrt + HSD + CLD + HLD + SMw + CSD.sqrt:SMw + HSD:SMw||SPECIES)
                       + (1|PLOT) + (1|TRAP)
                       + (1 + CSD.sqrt + HSD + CLD + HLD + SpMO|YEAR),
                       control = glmerControl(optCtrl = list(maxfun = 1e+06)), 
                       data = Data, family = binomial, verbose = 2, nAGQ = 1) # model fails to converge

# restart fit with last set of parameters
ss <- getME(SMwncsT2, c("theta","fixef"))
SMwncsT2u <- update(SMwncsT2, start = ss, control = glmerControl(optCtrl=list(maxfun=1e5))) # model fails to converge
# Use alternative optimizer (e.g.NLOPT_LN_BOBYQA)
ss <- getME(SMwncsT2, c("theta","fixef"))
SMwncsT2u2 <- update(SMwncsT2, start = ss, 
                       control = glmerControl(optimizer='nloptwrap', optCtrl=list(algorithm='NLOPT_LN_BOBYQA', maxeval=10000))) # Model fails to converge

# Fit CSD^1/2 model removing correlations among year AND species terms (model converges without warnings)
SMwzcT2 <- glmer(ALIVE ~ CSD.sqrt
                     + HSD + CLD + HLD + SMw + CSD.sqrt:SMw + HSD:SMw + SpMO + SpMO:SMw
                     + (1 + CSD.sqrt + HSD + CLD + HLD + SMw + CSD.sqrt:SMw + HSD:SMw||SPECIES)
                     + (1|PLOT) + (1|TRAP)
                     + (1 + CSD.sqrt + HSD + CLD + HLD + SpMO||YEAR),
                     control = glmerControl(optCtrl = list(maxfun = 1e+06)), 
                     data = Data, family = binomial, verbose = 2, nAGQ = 1)

# ... Continued routine (see Methods section) with fourth root of CSD and square and fourth roots of HSD, CLD and HLD (i.e., using "CSD.fort", "HSD.sqrt", "HSD.fort", "CLD.sqrt", "CLD.fort", "HLD.sqrt" or "HLD.fort"). 
# E.g.
# Fit CSD^1/4 (CSD.fort) model removing correlations among years only (returns singular fit)
SMwnycT3 <- glmer(ALIVE ~ CSD.fort + HSD + CLD + HLD + SMw + CSD.fort:SMw + HSD:SMw + SpMO + SpMO:SMw
                      + (1 + CSD.fort + HSD + CLD + HLD + SMw + CSD.fort:SMw + HSD:SMw|SPECIES)
                      + (1|PLOT) + (1|TRAP)
                      + (1 + CSD.fort + HSD +CLD + HLD + SpMO||YEAR),
                      control = glmerControl(optCtrl = list(maxfun = 1e+06)), 
                      data = Data, family = binomial, verbose = 2, nAGQ = 1) 

# Fit CSD^1/4 model removing correlations among species only (returns singular fit after update)
SMwncsT3 <- glmer(ALIVE ~ CSD.fort + HSD + CLD + HLD + SMw + CSD.fort:SMw + HSD:SMw + SpMO + SpMO:SMw
                       + (1 + CSD.fort + HSD + CLD + HLD + SMw + CSD.fort:SMw + HSD:SMw||SPECIES)
                       + (1|PLOT) + (1|TRAP)
                       + (1 + CSD.fort + HSD + CLD + HLD + SpMO|YEAR),
                       control = glmerControl(optCtrl = list(maxfun = 1e+06)), 
                       data = Data, family = binomial, verbose = 2, nAGQ = 1)

# Fit CSD^1/4 model removing correlations among years AND species (model converges without warnings)
SMwzcT3 <- glmer(ALIVE ~ CSD.fort + HSD + CLD + HLD + SMw + CSD.fort:SMw + HSD:SMw + SpMO + SpMO:SMw
                     + (1 + CSD.fort + HSD + CLD + HLD + SMw + CSD.fort:SMw + HSD:SMw||SPECIES)
                     + (1|PLOT) + (1|TRAP)
                     + (1+ CSD.fort + HSD +CLD + HLD + SpMO||YEAR),
                     control = glmerControl(optCtrl = list(maxfun = 1e+06)), 
                     data = Data, family = binomial, verbose = 2, nAGQ = 1)
### ...
# Convergence without warnings is achieved for every model when removing correlations among years AND species.
## COMPARISONS of linear & non-linear neighbor density models are done comparing AIC values of models including intercepts and slopes by Species & Years 
##     but excluding correlations among those random intercepts and slopes ('No correlation' models).

# The 'No correlation' untransformed densities model follows:
SMwzcT1 <- glmer(ALIVE ~ CSD + HSD + CLD + HLD + SMw + CSD:SMw + HSD:SMw + SpMO + SpMO:SMw
                     + (1 + CSD + HSD + CLD + HLD  + SMw + CSD:SMw + HSD:SMw||SPECIES)
                     + (1|PLOT) + (1|TRAP) 
                     + (1+CSD + HSD + CLD + HLD + SpMO||YEAR),
                     control = glmerControl(optCtrl = list(maxfun = 1e+06)),
                     data = Data, family = binomial, verbose = 2, nAGQ = 1)
# The 'No correlation' HSD^1/4 model (best no correlation model) follows: 
SMwzcT5 <- glmer(ALIVE ~ CSD + HSD.fort + CLD + HLD + SMw + CSD:SMw + HSD.fort:SMw + SpMO + SpMO:SMw
                     + (1 + CSD + HSD.fort + CLD + HLD + SMw + CSD:SMw + HSD.fort:SMw||SPECIES)
                     + (1|PLOT) + (1|TRAP)
                     + (1+ CSD + HSD.fort + CLD + HLD + SpMO||YEAR), 
                     control = glmerControl(optCtrl = list(maxfun = 1e+06)),
                     data = Data, family = binomial, verbose = 2, nAGQ = 1)# Best comparison model (results in Ext.Dta.Table 1, wet season only model)

# Comparison of the model with untransformed variables and the best transformed variable model (HSD^1/4)
anova(SMwzcT1, SMwzcT5) # Delta AIC=-58

# ALL SUBSEQUENT ALTERNATIVE MODELS USE HSD^1/4 (HSD.fort) AND NO-CORRELATIONS AMONG RANDOM TERMS.  

# ARE THERE INTERACTIONS BETWEEN SM & other neighbor densities (CLD & HLD)?

# Model with interaction between CLD and SM (reported in main text)
SMw_ZCxtr1<- glmer(ALIVE ~ CSD + HSD.fort + CLD + HLD + SMw + CSD:SMw + HSD.fort:SMw + SpMO + SpMO:SMw + CLD:SMw
                          + (1 + CSD + HSD.fort + CLD + HLD + SMw + CSD:SMw  + HSD.fort:SMw + CLD:SMw||SPECIES)
                          + (1|PLOT) + (1|TRAP)
                          + (1 + CSD + HSD.fort + CLD + HLD + SpMO||YEAR), 
                          control = glmerControl(optCtrl = list(maxfun = 1e+06)),
                          data = Data, family = binomial, verbose = 2, nAGQ = 1)

summary(SMw_ZCxtr1) # Interaction is NS (p=0.82)
anova(SMw_ZCxtr1, SMwzcT5) # complex model not better (Delta AIC = +1.6)

# Interaction between HLD and SM 
SMw_ZCxtr2 <- glmer(ALIVE ~ CSD + HSD.fort + CLD +HLD + SMw + CSD:SMw + HSD.fort:SMw + SpMO + SpMO:SMw 
                            + HLD:SMw
                            + (1 + CSD + HSD.fort + CLD + HLD + SMw 
                               + CSD:SMw  + HSD.fort:SMw
                               + HLD:SMw||SPECIES)
                            + (1|PLOT) + (1|TRAP)
                            + (1 + CSD + HSD.fort + CLD + HLD + SpMO||YEAR), 
                            control = glmerControl(optCtrl = list(maxfun = 1e+06)),
                            data = Data, family = binomial, verbose = 2, nAGQ = 1)

summary(SMw_ZCxtr2) # Interaction is NS (p=0.49)
anova(SMw_ZCxtr2, SMwzcT5) # complex model not better (Delta AIC = +2)

## COMPARISON OF MODELS using calculations of SM over different seasons (i.e. over the wet season only, dry season only and wet and dry seasons combined) ##
# Mean soil moisture over the dry season
SMd_ZC <- glmer(ALIVE ~ CSD + HSD.fort + CLD + HLD + SMd + CSD:SMd + HSD:SMd + SpMO + SpMO:SMd
                       + (1 + CSD + HSD.fort + CLD + HLD + SMd + CSD:SMd + HSD:SMd||SPECIES)
                       + (1|PLOT) + (1|TRAP)
                       + (1+CSD +HSD.fort +CLD + HLD +SpMO||YEAR), 
                       control = glmerControl(optCtrl = list(maxfun = 1e+06)), 
                       data = Data, family = binomial, verbose = 2, nAGQ = 1) # Results shown in Extended Data Table 1

summary(SMd_ZC) # CSD*SMd interaction is neg but ns (p=0.21) 
anova(SMwzcT5, SMd_ZC) # Model with SMd not better than with SMw (Delta AIC=43)

# Mean soil moisture over both seasons
SMb_ZC <- glmer(ALIVE ~ CSD + HSD.fort + CLD + HLD + SMb + CSD:SMb + HSD:SMb + SpMO  + SpMO:SMb
                       + (1 + CSD + HSD.fort + CLD + HLD + SMb + CSD:SMb + HSD:SMb||SPECIES)
                       + (1|PLOT) + (1|TRAP)
                       + (1 + CSD + HSD.fort + CLD + HLD + SpMO||YEAR), 
                       control = glmerControl(optCtrl = list(maxfun = 1e+06)),
                       data = Data, family = binomial, verbose = 2, nAGQ = 1) # results shown in Extended Data Table 1

summary(SMb_ZC) # CSD*SMb interaction is neg. (-0.10) and sig (p= 0.03) 
anova(SMwzcT5, SMb_ZC) # Model with SMb not better (Delta AIC=9)

# FIT 'MAXIMAL' (best fit) MODEL that is supported by data to minimize Type I error (Bolker et al. 2009; Barr et al. 2013). 
# I.e  remove correlations progressively (one at a time, two at a time...) until achieving convergence without warnings. 
# Previous fits for model comparisons showed that removing correlations among random terms by year returned a singular fit 
#   and that removing correlations by species achieved convergence without warnings. 
# Thus, approach maximum model by removing correlations for single random terms by species (i.e. HSD, CSD, LHD, LCD, SM, CSD*SM), one at a time. 
# Follow by removing two random correlations at a time and so on until achieving convergence.

# Removal of correlations for single terms (models did not converge after updates or returned singular fits)
# No correlations for HLD|Species (fails to converge)
bstNCS_HLD <- glmer(ALIVE ~ CSD + HSD.fort + CLD + HLD + SMw + CSD:SMw + HSD.fort:SMw + SpMO + SpMO:SMw
                             + (1 + CSD + HSD.fort + CLD + SMw + CSD:SMw + HSD.fort:SMw|SPECIES)
                             + (0 + HLD|SPECIES)
                             + (1|PLOT) + (1|TRAP)
                             + (1 + CSD + HSD.fort + CLD + HLD + SpMO|YEAR), 
                             control = glmerControl(optCtrl = list(maxfun = 1e+06)),
                             data = Data, family = binomial, verbose = 2, nAGQ = 1)

# No correlations for CLD|Species (singular fit)
bstNCS_CLD <- glmer(ALIVE ~ CSD + HSD.fort + CLD + HLD + SMw + CSD:SMw + HSD.fort:SMw + SpMO + SpMO:SMw
                             + (1 + CSD + HSD.fort  + HLD + SMw + CSD:SMw + HSD.fort:SMw|SPECIES)
                             + (0 + CLD |SPECIES)
                             + (1|PLOT) + (1|TRAP)
                             + (1 + CSD + HSD.fort + CLD + HLD + SpMO|YEAR), 
                             control = glmerControl(optCtrl = list(maxfun = 1e+06)),
                             data = Data, family = binomial, verbose = 2, nAGQ = 1)

# No correlations for HSD.fort|Species (singular fit)
bstNCS_HSD <- glmer(ALIVE ~ CSD + HSD.fort + CLD + HLD + SMw + CSD:SMw + HSD.fort:SMw + SpMO + SpMO:SMw
                             + (1 + CSD + CLD + HLD + SMw + CSD:SMw + HSD.fort:SMw|SPECIES)
                             + (0 + HSD.fort|SPECIES)
                             + (1|PLOT) + (1|TRAP)
                             + (1 + CSD + HSD.fort + CLD  + HLD + SpMO|YEAR), 
                             control = glmerControl(optCtrl = list(maxfun = 1e+06)),
                             data = Data, family = binomial, verbose = 2, nAGQ = 1)

# ... models without correlations for CSD, SMw, CSD:SMw or HSD:SMw|Species also returned singular fits

# Remove two correlations at a time. We fitted models for all 21 possible combinations of two terms: 
#    1) HSD + CSD, 2) HSD + CLD, 3) HSD + HLD, 4) HSD + SM, 5) HSD + CSD:SM, 6) HSD + HSD:SM 7) CSD + CLD,
#    8) CSD + HLD, 9) CSD + SM, 10) CSD + CSD:SM, 11) CSD + HSD:SM , 12) CLD + HLD, 13) CLD + SM, 14) CLD + CSD:SM,
#    15) CLD + HSD:SM, 16) HLD + SM, 17) HLD + CSD:SM, 18) HLD + HSD:SM, 19) SM + CSD:SM, 20) SM + HSD:SM, 
#    21) CSD:SM + HSD:SM. 

# e.g.:
# No correlations for HSD + CSD|Species (fails to converge)
bstNCS_HSD_CSD <- glmer(ALIVE ~ CSD + HSD.fort + CLD + HLD + SMw + CSD:SMw + HSD.fort:SMw + SpMO + SpMO:SMw
                           + (1 + CLD + HLD + SMw + CSD:SMw + HSD.fort:SMw|SPECIES)
                           + (0 + CSD + HSD.fort||SPECIES)
                           + (1|PLOT) + (1|TRAP)
                           + (1 + CSD + HSD.fort + CLD  + HLD + SpMO|YEAR), 
                           control = glmerControl(optCtrl = list(maxfun = 1e+06)),
                           data = Data, family = binomial, verbose = 2, nAGQ = 1)

# No correlations for HSD + CLD|Species (fails to converge)
bstNCS_HSD_CLD <-glmer(ALIVE ~ CSD + HSD.fort + CLD + HLD + SMw + CSD:SMw + HSD.fort:SMw + SpMO + SpMO:SMw
                       + (1 + CSD  + HLD + SMw + CSD:SMw + HSD.fort:SMw|SPECIES)
                       + (0 + HSD.fort + CLD ||SPECIES)
                       + (1|PLOT) + (1|TRAP)
                       + (1 + CSD + HSD.fort + CLD  + HLD + SpMO|YEAR), 
                       control = glmerControl(optCtrl = list(maxfun = 1e+06)),
                       data = Data, family = binomial, verbose = 2, nAGQ = 1)
#...

# models removing correlations for two terms did not converge or returned singular fits

# Remove three correlations at a time. We fitted models for all 35 possible combinations of three terms: 
#    1) HSD + CSD + CLD, 2) HSD + CSD + HLD, 3) HSD + CSD + SM, 4) HSD + CSD + CSD:SM,  5) HSD + SM + HSD:SM,
#    6) HSD + CLD + HLD, 7) HSD + CLD + SM , 8) HSD + CLD + CSD:SM, 9) HSD + CLD + HSD:SM, 10) HSD + HLD + SM,
#    11) HSD + HLD + CSD:SM, 12) HSD + HLD + HSD:SM, 13) HSD + SM + CSD:SM, 14) HSD + SM + HSD:SM,
#    15) HSD + CSD:SM + HSD:SM, 16) CSD + CLD + HLD, 17) CSD + CLD + SM, 18) CSD + CLD + CSD:SM,
#    19) CSD + CLD + HSD:SM, 20) CSD + HLD + SM, 21) CSD + HLD + CSD:SM, 22) CSD + HLD + HSD:SM, 
#    23) CSD + SM + CSD:SM, 24) CSD + SM + HSD:SM, 25) CSD + CSD:SM + HSD:SM, 26) CSD + HLD + SM, 
#    27) CSD + HLD + CSD:SM, 28) CSD + HLD + HSD:SM, 29) CLD + SM + CSD:SM, 30) CLD + SM + HSD:SM,
#    31) CLD + CSD:SM + HSD:SM, 32) HLD + SM + CSD:SM, 33) HLD + SM + HSD:SM, 34) HLD + CSD:SM + HSD:SM,
#    35) SM + CSD:SM + HSD:SM

#The model removing the correlations of HSD, CSD*SM and the HSD*SM interaction by species converged without warnings:  
SMw_maxm <- glmer(ALIVE ~ CSD + HSD.fort  + CLD + HLD + SMw  + CSD:SMw + HSD.fort:SMw + SpMO + SpMO:SMw
                        + (1 + CSD + CLD + HLD + SMw|SPECIES)
                        + (0 + HSD.fort + CSD:SMw + HSD.fort:SMw||SPECIES)
                        + (1|PLOT) + (1|TRAP)
                        + (1 + CSD + HSD.fort + CLD + HLD +SpMO|YEAR), 
                        control = glmerControl(optCtrl = list(maxfun = 1e+06)),
                        data = Data, family = binomial, verbose = 2, nAGQ = 1)


summary(SMw_maxm) # results shown in Fig.2, Fig. 3 & Extended Data Fig. 3

# ANALYSIS OF RESIDUALS for BEST MODEL#####
bestmodel<-SMw_maxm
# requires DHARMa package
# test of residuals
Model<-bestmodel
simulationOutput.1 <- simulateResiduals(fittedModel = Model, n =2500, use.u = T)# Increase default simulations by an order of magnitude. use.u=T means simulations conditional on fitted random effects.

# Uniform quantile-quantile plot (EDF 6)
plotQQunif(simulationOutput.1,testUniformity = F, testOutliers = F, testDispersion = F, main=NULL)
testUniformity(simulationOutput.1, plot=F) # tests deviation from uniformity
testDispersion(simulationOutput.1, plot=F) # test for over/underdispersion

# Conditional residuals against predictors (EDF7)
# a) CSD Dharma conditional residuals plot
plotResiduals(simulationOutput.1, Data$CSD, quantreg=T, smoothScatter=T, rank=F, nrpoints=0, col="grey70")#use nrpoints=Inf to show all points

# b) HSD Dharma conditional residuals plot
plotResiduals(simulationOutput.1, Data$HSD.fort, quantreg=T,smoothScatter=T, rank=F, nrpoints=0)

# c) CSD ARM's conditional residuals Binned plot
y<-residuals(Model,"response")# raw conditional residuals
binnedplot(Data$CSD,y, col.int = T, xlab="Cospecific seedling density", ylab="Average residual", main=NULL, xaxt="n")
axis(1)

# d) HSD ARM's conditional residuals Binned plot
binnedplot(Data$HSD.fort,y, col.int = T, xlab="Heterospecific seedling density", ylab="Average residual", main= NULL,xaxt="n")
axis(1)

# e) CLD Dharma conditional residuals plot
plotResiduals(simulationOutput.1, Data$CLD, quantreg=T,smoothScatter=T, rank=F, nrpoints=0)

# f) HLD Dharma conditional residuals plot
plotResiduals(simulationOutput.1, Data$HLD, quantreg=T,smoothScatter=T, rank=F, nrpoints=0)

# g) CLD ARM's conditional residuals Binned plot
binnedplot(Data$CLD,y, col.int = T, xlab="Large conspecific density", ylab="Average residual", main=NULL, xaxt="n")
axis(1)

# h) HLD ARM's conditional residuals Binned plot
binnedplot(Data$HLD, y, col.int = T,xlab="Large heterospecific density", ylab="Average residual", main= NULL,xaxt="n")
axis(1)

# i) SpMO Dharma conditional residuals plot
plotResiduals(simulationOutput.1, Data$SpMO,  quantreg=T,smoothScatter=T, rank=F, nrpoints=0)

# j) Soil Moisture Dharma conditional residuals plot
plotResiduals(simulationOutput.1, Data$SMw, quantreg=T,smoothScatter=T, rank=F, nrpoints=0)

# k) SpMO ARM's conditional residuals Binned plot
binnedplot(Data$SpMO , y, col.int = T, xlab="Species moisture optima", ylab="Average residual", main= NULL, xaxt="n", ylim=c(-0.15,0.17))
axis(1)

# l) Soil Moisture ARM's conditional residuals Binned plot
binnedplot(Data$SMw, y, col.int = T, xlab="Soil moisture", ylab="Average residual", main = NULL, xaxt="n", ylim=c(-0.032,0.032))
axis(1)

# STABILIZATION CNDD vs HNDD ####
## Is there evidence for species stabilization, i.e. CNDD>HNDD? 
# Results in EDF 8
# Extract SMw values per cohort
SMw<- unique(Data[order(Data$YEAR),c("SMw")])

# Parameter simulations 
BestModsim<-arm::sim(bestmodel, n.sims = 10000)

multi.fun <- function(x) {
  c(mean = mean(x), LCI = quantile(x, probs=c(0.025)), UCI = quantile(x, probs=c(0.975)))
}

# SURVIVAL probability AT MEDIAN VALUES of all variables except SM set at 0.25, 0.5 and 0.75 pctl
vsm<-quantile(SMw, probs=c(0.025, 0.5, 0.75))
CNDDmsim_vsm<-list()
for (i in 1:3) {
  CNDDmsim_vsm[[i]]=
    invlogit(BestModsim@fixef[,"(Intercept)"] 
             + (BestModsim@fixef[,"CSD"]*0)
             + (BestModsim@fixef[,"SMw"]* vsm[i])
             + (BestModsim@fixef[,"CSD:SMw"]*vsm[i]*0))
}

CNDDm.vsm<-as.data.frame(matrix(unlist(lapply(CNDDmsim_vsm, multi.fun)), nrow=3,ncol=3, byrow =T))# mean and 95% CI of surv. prob
names(CNDDm.vsm)<-c("CNDD.mean", "CNDD.2.5%", "CNDD.97.5%")
rownames(CNDDm.vsm)<-c("SM25%","SM50%","SM75%")

# Survival p with INCREASE in CSD (median + 1 individual) at 25, 50 & 75 percentiles of SM and median values of other predictors
CNDDlsim_vsm<-list()
for (i in 1:3) {
  CNDDlsim_vsm[[i]]=
    invlogit(BestModsim@fixef[,"(Intercept)"] 
             + (BestModsim@fixef[,"CSD"]*0.1)# 0.1 = the mean centered and IQR standardized CSD value
             + (BestModsim@fixef[,"SMw"]* vsm[i])
             + (BestModsim@fixef[,"CSD:SMw"]*vsm[i]*0.1))
}

CNDDm1.vsm<-as.data.frame(matrix(unlist(lapply(CNDDlsim_vsm, multi.fun)), nrow=3,ncol=3, byrow =T))# mean and 95% CI of surv. prob
names(CNDDm1.vsm)<-c("CNDD.mean", "CNDD.2.5%", "CNDD.97.5%")
rownames(CNDDm1.vsm)<-c("SM25%","SM50%","SM75%")

# Survival difference of increasing 1 conspecific seedling individual at median density values and different soil moisture
listA<-CNDDlsim_vsm
listB<-CNDDmsim_vsm
CNDDm.diff<-mapply(function(X,Y) {
  X-Y
}, X=listA, Y=listB, SIMPLIFY=F)

CNDDm.diff.vsm<-as.data.frame(matrix(unlist(lapply(CNDDm.diff, multi.fun)), nrow=3,ncol=3, byrow =T))# mean and 95% CI of surv. prob (Values reported in EDF 8)
names(CNDDm.diff.vsm)<-c("CNDDdf.mean", "CNDDdf.2.5%", "CNDDdf.97.5%")
rownames(CNDDm.diff.vsm)<-c("SM25%","SM50%","SM75%")

# Survival p with INCREASE IN HSD (median + 1 individual) at 25 & 75 percentiles of SM and median values of other predictors
HDDlsim_vsm<-list()
for (i in 1:3){
  HDDlsim_vsm[[i]]=
    invlogit(BestModsim@fixef[,"(Intercept)"] 
             + (BestModsim@fixef[,"HSD.fort"]*0.06622754)# Median centered IQR std. value
             + (BestModsim@fixef[,"SMw"]* vsm[i])
             + (BestModsim@fixef[,"HSD.fort:SMw"]*vsm[i]*0.06622754))
}

HDDm1.vsm<-as.data.frame(matrix(unlist(lapply(HDDlsim_vsm, multi.fun)), nrow=3,ncol=3, byrow =T))# mean and 95% CI of surv. prob
names(HDDm1.vsm)<-c("HDD.mean", "HDD.2.5%", "HDD.97.5%")
rownames(HDDm1.vsm)<-c("SM25%","SM50%","SM75%")

# SURVIVAL DIFFERENCE of increasing 1 HS individual at median density values and different soil moisture
listA<-HDDlsim_vsm
listB<-CNDDmsim_vsm# This is actually survival at median values of all density terms so not exclusive to CNDD
HDDm.diff<-mapply(function(X,Y) {
  X-Y
}, X=listA, Y=listB, SIMPLIFY=F)

HDDm.diff.vsm<-as.data.frame(matrix(unlist(lapply(HDDm.diff, multi.fun)), nrow=3,ncol=3, byrow =T))# mean and 95% CI of surv. prob (Values reported in EDF 8)
names(HDDm.diff.vsm)<-c("HDDdf.mean", "HDDdf.2.5%", "HDDdf.97.5%")
rownames(HDDm.diff.vsm)<-c("SM25%","SM50%","SM75%")

# DIVERSITY ANALYSES ####
## SIMULATED CHANGES IN DIVERSITY  #### 
# Fig. 4 and Extended Data Fig. 2 
## USE BEST 'MAXIMAL' MODEL TO SIMULATE INDIVIDUAL SEEDLING SURVIVAL WITHOUT THE EFFECTS OF SMw*CSD & SMw*SpMO
# Prediction using ALL EFFECTS
pred.all.eff <- predict(bestmodel,newdata= Data,type="response")

# GET RANDOM AND FIXED EFFECTS
m.theta <- getME(bestmodel, c("theta")) # random effect parameters
m.beta <- getME(bestmodel, c("fixef")) # fixed effects parameters

# SET FIXED EFFECTS TO ZERO and remove associated random slopes
# REMOVE INTERACTION BETWEEN CSD & SMw (fixed and random effects)
m.betanicm <- m.beta # new vector to modify
fixef(bestmodel) # show coefficients
m.betanicm[c(8)] <- 0 # sets interaction effect to zero 
bestmodel@call # show model
pred.n.i.c.m <- predict(bestmodel, newdata = Data, newparams= list(theta= m.theta, beta= m.betanicm), 
                        re.form= ~(1 + CSD + CLD + HLD + SMw |SPECIES) 
                                   + (0 + HSD.fort #+ CSD:SMw 
                                     + HSD.fort:SMw|| SPECIES) 
                        + (1|PLOT) + (1|TRAP)
                        + (1 + CSD + HSD.fort + CLD + HLD + SpMO |YEAR), type="response")

# REMOVE INTERACTION BETWEEN SpMO & SMw
# Note  dropping the SpMO:SMw interaction does not change the random structure of the model because
# SpMO is a property of species and SMw is a property of year so the interaction SpMO:SMw does not appear as a random effect.
m.betanismmo <- m.beta
m.betanismmo[c(10)] <- 0 # sets interaction effect to zero 
pred.n.i.sm.mo <- predict(bestmodel, newdata= Data, newparams= list(theta= m.theta, beta= m.betanismmo), 
                          re.form= ~(1 + CSD + CLD + HLD + SMw|SPECIES) 
                                     + (0 + HSD.fort + CSD:SMw + HSD.fort:SMw||SPECIES)
                          + (1|PLOT) + (1|TRAP)
                          + (1 + CSD + HSD.fort + CLD + HLD + SpMO |YEAR), type="response") 

# SIMULATE COMMUNITIES USING SURVIVAL PREDICTIONS AND CALCULATE DIVERSITY
dta.summ <- data.frame(YEAR = Data$YEAR,
                       SPECIES = Data$SPECIES,
                       predall = pred.all.eff, # All effects
                       prednicsm = pred.n.i.c.m, # No Interaction CSD:SMw
                       prednismmo = pred.n.i.sm.mo) # No Interaction SpMO:SMw

## Randomly draw probabilities from uniform distribution to decide fate of individuals in modeled communities 
##     (surv = 0 when random draw is higher than the modeled survival)
#library(foreach)
#library(doParallel)
comb <- function(...) {
  mapply('cbind', ..., SIMPLIFY=FALSE)
} # function to combine simulation results (D1 and D2) into matrices with 20 rows (years) x 10000 simulations (columns) in the foreach function below

registerDoParallel(cores=8)
# Div all effects ####
div.all <- foreach(i=1:10000, .combine='comb', .multicombine=TRUE, .packages=c('reshape2','vegan'), .inorder=F) %dopar% {
  rndsrv <- runif(nrow(dta.summ), 0, 1) # draw random probability
  rndAlive.all <- ifelse(rndsrv<=dta.summ$predall, 1, 0) # define seedling fate
  dta.summ$rndAlive.all <- rndAlive.all
  # Create matrix of spp x yr for div calculations
  SpMtrxAll.rnd <- dcast(dta.summ, YEAR~SPECIES, value.var="rndAlive.all", sum, fill=0)
  # Calc Div indices
  D1 <- exp(diversity(SpMtrxAll.rnd[,-c(1)], index = "shannon", MARGIN = 1, base = exp(1))) # exponential converts to hill number D1
  D2 <- diversity(SpMtrxAll.rnd[,-c(1)], index = "invsimpson", MARGIN = 1, base = exp(1)) # Inverse of Simpson equals D2 
  list(D1, D2)
} # List with D1 and D2 of 10,000 simulated communities using all effects for each of the 20 years of data
#stopImplicitCluster()
names(div.all)<-c("D1.all","D2.all")

# Div  No Int Cons : Soil moist ####
div.nicsm <- foreach(i=1:10000, .combine='comb', .multicombine=TRUE, .packages=c('reshape2','vegan'), .inorder=F) %dopar% {
  rndsrv <- runif(nrow(dta.summ), 0, 1) 
  rndAlive.nicsm <- ifelse(rndsrv<=dta.summ$prednicsm, 1, 0)
  dta.summ$rndAlive.nicsm <- rndAlive.nicsm
  # Create matrix of spp x yr for div calculations
  SpMtrxnicsm.rnd <- dcast(dta.summ, YEAR~SPECIES, value.var="rndAlive.nicsm", sum, fill=0)
  # Calc Div indices
  D1 <- exp(diversity(SpMtrxnicsm.rnd[,-c(1)], index = "shannon", MARGIN = 1, base = exp(1)))
  D2 <- diversity(SpMtrxnicsm.rnd[,-c(1)], index = "invsimpson", MARGIN = 1, base = exp(1))
  list(D1, D2)
} # Div of communities modeled without CSD:SM
#stopImplicitCluster()
names(div.nicsm)<-c("D1.nicsm","D2.nicsm")

# Div No Int soil moist: Moist opt ####
div.nismmo <- foreach(i=1:10000, .combine='comb', .multicombine=TRUE, .packages=c('reshape2','vegan'), .inorder=F) %dopar% {
  rndsrv <- runif(nrow(dta.summ), 0, 1) 
  rndAlive.nismmo <- ifelse(rndsrv<=dta.summ$prednismmo, 1, 0)
  dta.summ$rndAlive.nismmo <- rndAlive.nismmo
  # Create matrix of spp x yr for div calculations
  SpMtrxnismmo.rnd <- dcast(dta.summ, YEAR~SPECIES, value.var="rndAlive.nismmo", sum, fill=0)
  # Calc Div indices
  D1 <- exp(diversity(SpMtrxnismmo.rnd[,-c(1)], index = "shannon", MARGIN = 1, base = exp(1)))
  D2 <- diversity(SpMtrxnismmo.rnd[,-c(1)], index = "invsimpson", MARGIN = 1, base = exp(1))
  list(D1, D2)
} # Div of communities modeled without SM:SpMO
stopImplicitCluster()
names(div.nismmo)<-c("D1.nismmo","D2.nismmo") 

# D2 CORRELATIONS & SLOPES OF RELATIONSHIP WITH SM ####
#  OBSERVED DATA SLOPE & CORRELATION
gls.obs.D2 <- gls(Dlt.D2 ~ SMw.raw, data = Div.all, weights = varPower(form=~SMw.raw)) # Same model as at the beginning of code (observed data)
summary(gls.obs.D2) # SMw slope = 3.19 p= 0.005 (Fig 1 Beta)
s.cor.obs.D2<-cor.test(Div.all$SMw.raw, Div.all$Dlt.D2, method ="spearman") # Spearman for heteroscedastic errors (rs=0.62), p=0.004 (legend of Fig. 1)

## SIMULATED DATA SLOPES AND CORRELATIONS
# MODEL WITH ALL EFFECTS
funD2rel= function (x) {(x - Div.all$D2Rec)/(Div.all$D2Rec)} # calculates relative change for all x simulations
Dlt.D2.sim <- apply(div.all[[2]], MARGIN=2, FUN=funD2rel)

# Compare GLS models with different variance structures (using mean of simulated changes)
Dlt.D2.sim.sw <- as.data.frame(cbind(Dlt.D2.sim, Div.all$SMw.raw))
Dlt.D2.sim.sw <- Dlt.D2.sim.sw[,c(10001,1:10000)]
names(Dlt.D2.sim.sw)[1] <- "SMw.raw"
meant <- apply(Dlt.D2.sim.sw[,c(2:10001)], MARGIN=1, FUN=mean)*100
dtat.D2.all <- cbind.data.frame(Dlt.D2.sim.sw[,1], meant)
names(dtat.D2.all)[1] <- "SMw.raw"
gls.1 <- gls(meant ~ SMw.raw, data= dtat.D2.all)
gls.2 <- gls(meant ~ SMw.raw, data= dtat.D2.all, weights=varPower(form=~SMw.raw))
gls.3 <- gls(meant ~ SMw.raw, data= dtat.D2.all, weights=varExp(form=~SMw.raw)) 
anova(gls.1, gls.2, gls.3) # heteroscedastic errors not better (Delta AIC < -1)

# Fit slope to each simulations using best mean model (Results shown in Fig. 4a)
dta_l <- setNames(lapply(names(Dlt.D2.sim.sw)[-1], function(x) cbind(Dlt.D2.sim.sw[1], Dlt.D2.sim.sw[x])), names(Dlt.D2.sim.sw)[-1])
for (i in 1:length(dta_l)) {names(dta_l[[i]])[2] <- "x"}
uw.slope<- function (X) {gls(x*100 ~ SMw.raw, data= X)$coefficients[2]} # best model for mean of simulations
slopes.D2.sw.sim.l <- lapply(X=dta_l,FUN=uw.slope)
slopes.D2.sw.sim <- unlist(slopes.D2.sw.sim.l)
h.slopes.D2.all <- hist(slopes.D2.sw.sim, breaks=16)
mean(slopes.D2.sw.sim) # Mean slope Fig 4b
quantile(slopes.D2.sw.sim, probs=c(0.025,0.975)) # CI Fig. 4b 

# Correlation of SMw with each simulation (Extended Data Fig. 2e)
# Use Spearman coefficient for comparison with observed correlation
s.cor.DltD2all <- apply(Dlt.D2.sim, MARGIN=2, FUN=cor,y=Div.all$SMw.raw, method = "spearman") # comparison with fig 1
mean(s.cor.DltD2all) # mean rs
quantile(s.cor.DltD2all, probs=c(0.025,0.975)) # CI rs
h.s.cor.all.D2 <- hist(s.cor.DltD2all,breaks=12)

# MODEL NO INT SpMO:SMw
names(div.nismmo)
Dlt.D2.nismmo.sim <- apply(div.nismmo[[2]], MARGIN=2, FUN=funD2rel)

# Slopes of simulations
# Compare GLS models
Dlt.D2.nismmo.sim.sw <- as.data.frame(cbind(Dlt.D2.nismmo.sim, Div.all$SMw.raw))
Dlt.D2.nismmo.sim.sw <- Dlt.D2.nismmo.sim.sw[,c(10001,1:10000)]
names(Dlt.D2.nismmo.sim.sw)[1] <- "SMw.raw"
meant <- apply(Dlt.D2.nismmo.sim.sw, MARGIN=1, FUN=mean)*100
dtat.D2.nismmo <- cbind.data.frame(Dlt.D2.nismmo.sim.sw[,1], meant)
names(dtat.D2.nismmo)[1] <- "SMw.raw"
gls.1 <- gls(meant ~ SMw.raw, data= dtat.D2.nismmo)
gls.2 <- gls(meant ~ SMw.raw, data= dtat.D2.nismmo, weights=varPower(form=~SMw.raw))
gls.3 <- gls(meant ~ SMw.raw, data= dtat.D2.nismmo, weights=varExp(form=~SMw.raw)) #
anova(gls.1, gls.2, gls.3) # models with heteroscedastic errors not better (delta AIC< -1)

# slopes of all simulations (Results shown in Fig. 4a)
dta.nismmo_l <- setNames(lapply(names(Dlt.D2.nismmo.sim.sw)[-1], function(x) cbind(Dlt.D2.nismmo.sim.sw[1], Dlt.D2.nismmo.sim.sw[x])), names(Dlt.D2.nismmo.sim.sw)[-1])
for (i in 1:length(dta.nismmo_l)) {names(dta.nismmo_l[[i]])[2]<-"x"}
slopes.D2.sw.nismmo.sim.l <- lapply(X=dta.nismmo_l,FUN=uw.slope)
slopes.D2.sw.nismmo.sim <- unlist(slopes.D2.sw.nismmo.sim.l)
h.slopes.D2.nismmo <- hist(slopes.D2.sw.nismmo.sim, breaks=16)
mean(slopes.D2.sw.nismmo.sim) # Mean slope Fig 4c
quantile(slopes.D2.sw.nismmo.sim, probs=c(0.025,0.975)) # CI Fig 4c

# Correlation w simulations (Extended data Fig.2f)
s.cor.DltD2nismmo <- apply(Dlt.D2.nismmo.sim, MARGIN=2, FUN=cor,y=Div.all$SMw.raw, method = "spearman")
mean(s.cor.DltD2nismmo) # mean rs 
quantile(s.cor.DltD2nismmo, probs=c(0.025,0.975)) # CI rs
h.s.cor.nismmo.D2 <- hist(s.cor.DltD2nismmo, breaks=11)

# MODEL W/O INT CSD:SM
names(div.nicsm)
Dlt.D2.nicsm.sim <- apply(div.nicsm[[2]], MARGIN=2, FUN=funD2rel)

# slopes of simulations
## Comparisons of models with and without weights: mean of simulated changes
Dlt.D2.nicsm.sim.sw <- as.data.frame(cbind(Dlt.D2.nicsm.sim,Div.all$SMw.raw))
Dlt.D2.nicsm.sim.sw <- Dlt.D2.nicsm.sim.sw[,c(10001,1:10000)]
names(Dlt.D2.nicsm.sim.sw)[1] <- "SMw.raw"
meant <- apply(Dlt.D2.nicsm.sim.sw, MARGIN=1, FUN=mean)*100
dtat.D2.nicsm <- cbind.data.frame(Dlt.D2.nicsm.sim.sw[,1], meant)
names(dtat.D2.nicsm)[1] <- "SMw.raw"
gls.1 <- (gls(meant ~ SMw.raw, data= dtat.D2.nicsm))
gls.2 <- (gls(meant ~ SMw.raw, data= dtat.D2.nicsm, weights=varPower(form=~SMw.raw))) 
gls.3 <- (gls(meant ~ SMw.raw, data= dtat.D2.nicsm, weights=varExp(form=~SMw.raw)))   
anova(gls.1, gls.2, gls.3) # models with heteroscedastic errors not better (Delta AIC = 0.1)

# slopes of all simulations (Results showm in Fig. 4a)
dta.nicsm_l <- setNames(lapply(names(Dlt.D2.nicsm.sim.sw)[-1], 
                               function(x) cbind(Dlt.D2.nicsm.sim.sw[1], Dlt.D2.nicsm.sim.sw[x])),
                        names(Dlt.D2.nicsm.sim.sw)[-1])
for (i in 1:length(dta.nicsm_l)) {names(dta.nicsm_l[[i]])[2]<-"x"}
slopes.D2.sw.nicsm.sim.l <- lapply(X=dta.nicsm_l,FUN=uw.slope)  
slopes.D2.sw.nicsm.sim <- unlist(slopes.D2.sw.nicsm.sim.l)
h.slopes.D2.nicsm <- hist(slopes.D2.sw.nicsm.sim, breaks=16)
mean(slopes.D2.sw.nicsm.sim) # Mean slope Fig 4d
quantile(slopes.D2.sw.nicsm.sim, probs=c(0.025,0.975)) # CI Fig 4d

# Correlation w simulations (Extended Data Fig. 2g)
s.cor.DltD2nicsm <- apply(Dlt.D2.nicsm.sim, MARGIN=2, FUN=cor,y=Div.all$SMw.raw, method = "spearman")
mean(s.cor.DltD2nicsm) # mean rs
quantile(s.cor.DltD2nicsm, probs=c(0.025,0.975)) # CI rs
h.s.cor.nicsm.D2 <- hist(s.cor.DltD2nicsm, breaks=11)

# Summary of Means and quantiles of SM-Delta Diversity slope for all simulations (Fig 4)
mean(slopes.D2.sw.sim); quantile(slopes.D2.sw.sim, probs=c(0.025,0.975)) # All effects
mean(slopes.D2.sw.nismmo.sim);quantile(slopes.D2.sw.nismmo.sim, probs=c(0.025,0.975)) # NI SpMO:SM
mean(slopes.D2.sw.nicsm.sim); quantile(slopes.D2.sw.nicsm.sim, probs=c(0.025,0.975)) # NI CSD:SM

# Same code was run for D1 (Extended Data Fig. 2 a-d)

## IMPORTANCE of first-year DIVERSITY CHANGES ####
# Results in EDF4
# The analyses of correlations and predictive power of cohorts use data beyond 2015 as are not dependent on FDP census data.

# Extended Data Figure 4a
# CORREL. OF DIVERSITY OF 1Y-OLD SEEDLING COHORTS TROUGH TIME (i.e. with the diversity of the same seedling cohorts two through 15 years after recruitment)
# correlate DIV of 1y-old cohorts with their diversity 1,2,3... n yrs later: the i subscripts defines the appropriate cohort age 'x' (column) and year (row) when each cohort turned 'x' years-old 
## D1
Cor1YD1 <- data.frame(corPair=character(), cor.Est=numeric(), cor.p=numeric(), cor.CIlb=numeric(), cor.CIub=numeric(), cor.N=numeric())  
for(i in 1:14) { # min N = 10 for i=14
  cortest <- cor.test(DivDb20$D1.1Yr,
                      eval(parse(text=paste0("DivDb20$D1.", i+1, "Yr[(1:nrow(DivDb20))+", i, "]"))),
                      na.action = na.omit) 
  Cor1YD1[i,1] <- paste("cor.D1.1Yr_", i+1, "Yr", sep="")
  Cor1YD1[i,2] <- cortest$estimate
  Cor1YD1[i,3] <- cortest$p.value
  Cor1YD1[i,4] <- ifelse(sum(!is.na(DivDb20$D1.1Yr &
                                eval(parse(text=paste0("DivDb20$D1.",i+1,"Yr[(1:nrow(DivDb20))+",i,"]")))))>3,
                                cortest$conf.int[1], NA)
  Cor1YD1[i,5] <- ifelse(sum(!is.na(DivDb20$D1.1Yr &
                                eval(parse(text=paste0("DivDb20$D1.",i+1,"Yr[(1:nrow(DivDb20))+",i,"]")))))>3,
                                cortest$conf.int[2], NA) 
  Cor1YD1[i,6] <- sum(!is.na(DivDb20$D1.1Yr &
                             eval(parse(text=paste0("DivDb20$D1.",i+1,"Yr[(1:nrow(DivDb20))+",i,"]")))))
}
print(Cor1YD1) # results in EDF 4a for D1

## D2
Cor1YD2 <- data.frame(corPair=character(), cor.Est=numeric(), cor.p=numeric(), cor.CIlb=numeric(), cor.CIub=numeric(), cor.N=numeric())
for( i in 1:14){ 
  cortest <- cor.test(DivDb20$D2.1Yr,
                      eval(parse(text=paste0("DivDb20$D2.", i+1, "Yr[(1:nrow(DivDb20))+", i, "]"))),
                      na.action = na.omit) 
  Cor1YD2[i,1] <- paste("cor.D2.1Yr_", i+1, "Yr", sep="")
  Cor1YD2[i,2] <- cortest$estimate
  Cor1YD2[i,3] <- cortest$p.value
  Cor1YD2[i,4] <- ifelse(sum(!is.na(DivDb20$D2.1Yr &
                                eval(parse(text=paste0("DivDb20$D2.", i+1, "Yr[(1:nrow(DivDb20))+", i, "]")))))>3,
                                cortest$conf.int[1], NA)
  Cor1YD2[i,5] <- ifelse(sum(!is.na(DivDb20$D2.1Yr &
                                eval(parse(text=paste0("DivDb20$D2.", i+1, "Yr[(1:nrow(DivDb20))+", i, "]")))))>3,
                                cortest$conf.int[2], NA)
  Cor1YD2[i,6] <- sum(!is.na(DivDb20$D2.1Yr &
                              eval(parse(text=paste0("DivDb20$D2.", i+1, "Yr[(1:nrow(DivDb20))+", i, "]")))))
}
print(Cor1YD2)# results in EDF 4a for D2

# CORREL. OF DIVERSITY OF RECRUIT COHORTS TROUGH TIME
# USED TO COMPARE CORREL OF SEEDLING DIVERSITY AT LATER STAGES WITH DIV AT RECRUITMENT VS A YEAR LATER (EDF4b)
# D1
CorRecD1 <- data.frame(corPair=character(), cor.Est=numeric(), cor.p=numeric(), cor.CIlb=numeric(), cor.CIub=numeric(), cor.N=numeric())
for( i in 1:15){ # min N = 10 for i=15
  cortest<-cor.test(DivDb20$D1.Rec,
                    eval(parse(text=paste0("DivDb20$D1.",i,"Yr[(1:nrow(DivDb20))+",i,"]"))),
                    na.action = na.omit)
  CorRecD1[i,1] <- paste("cor.D1.rec_",i,"Yr", sep="")
  CorRecD1[i,2] <- cortest$ estimate
  CorRecD1[i,3] <- cortest$ p.value
  CorRecD1[i,4] <- ifelse(sum(!is.na(DivDb20$D1.Rec &
                              eval(parse(text=paste0("DivDb20$D1.",i,"Yr[(1:nrow(DivDb20))+",i,"]")))))>3,
                               cortest$conf.int[1], NA)
  CorRecD1[i,5] <- ifelse(sum(!is.na(DivDb20$D1.Rec &
                              eval(parse(text=paste0("DivDb20$D1.",i,"Yr[(1:nrow(DivDb20))+",i,"]")))))>3,
                               cortest$conf.int[2], NA) 
  CorRecD1[i,6] <- sum(!is.na(DivDb20$D1.Rec &
                              eval(parse(text=paste0("DivDb20$D1.",i,"Yr[(1:nrow(DivDb20))+",i,"]")))))
}

#D2 
CorRecD2 <- data.frame(corPair=character(), cor.Est=numeric(), cor.p=numeric(), cor.CIlb=numeric(), cor.CIub=numeric(), cor.N=numeric())
for( i in 1:15){ 
  cortest<-cor.test(DivDb20$D2.Rec,
                    eval(parse(text=paste0("DivDb20$D2.",i,"Yr[(1:nrow(DivDb20))+",i,"]"))),
                    na.action = na.omit)
  CorRecD2[i,1] <- paste("cor.D2.rec_",i,"Yr", sep="")
  CorRecD2[i,2] <- cortest$ estimate
  CorRecD2[i,3] <- cortest$ p.value
  CorRecD2[i,4] <- ifelse(sum(!is.na(DivDb20$D2.Rec &
                              eval(parse(text=paste0("DivDb20$D2.",i,"Yr[(1:nrow(DivDb20))+",i,"]")))))>3,
                               cortest$conf.int[1], NA)
  CorRecD2[i,5] <- ifelse(sum(!is.na(DivDb20$D2.Rec &
                              eval(parse(text=paste0("DivDb20$D2.",i,"Yr[(1:nrow(DivDb20))+",i,"]")))))>3,
                               cortest$conf.int[2], NA) 
  CorRecD2[i,6] <- sum(!is.na(DivDb20$D2.Rec &
                              eval(parse(text=paste0("DivDb20$D2.",i,"Yr[(1:nrow(DivDb20))+",i,"]")))))
}

# Extended Data Figure 4b
# TESTS OF DIFFERENCE IN STRENGTH OF CORRELATION OF DIV AT LATER STAGES WITH RECRUITS VS 1y-OLD DIV ####
# The Dunn & Clark test is recommended in Steiger (1980).
# TEST FOR RELATED GROUPS 
cor.rec.Y1.YrX.D1 <- data.frame(coh.age= character(), r.1y= numeric(), r.Rec= numeric(), Diff.r= numeric(), z.stat= numeric(), 
                                p.value= numeric(), r2.1y= numeric(), r2.Rec= numeric(), Diff.r2= numeric(), n= numeric())

cor.rec.Y1.YrX.D2 <- data.frame(coh.age= character(), r.1y= numeric(), r.Rec= numeric(), Diff.r= numeric(), z.stat= numeric(), 
                                p.value= numeric(), r2.1y= numeric(), r2.Rec= numeric(), Diff.r2= numeric(), n= numeric())

for (i in 2:10){
  yr <- i #this number equals the No of years after recruitment being compared (for the recruitment table)
  #D1
  cor.rec.Y1.YrX.D1[i-1,1] <- paste(i,"yr")
  cor.rec.Y1.YrX.D1[i-1,2] <- round(Cor1YD1[yr-1,2],3)
  cor.rec.Y1.YrX.D1[i-1,3] <- round(CorRecD1[yr,2],3)
  cor.rec.Y1.YrX.D1[i-1,4] <- round(Cor1YD1[yr-1,2] - CorRecD1[yr,2],3)
  cor.rec.Y1.YrX.D1[i-1,5] <- round(as.numeric(cocor.dep.groups.overlap(r.jk = CorRecD1[yr,2], r.jh = Cor1YD1[yr-1,2], r.kh = CorRecD1[1,2], n=CorRecD1[yr,6], 
                                                                        alternative ="lower")@dunn1969[2]),2) # Dunn & Clark test statistic 
  cor.rec.Y1.YrX.D1[i-1,6] <- round(as.numeric(cocor.dep.groups.overlap(r.jk= CorRecD1[yr,2],r.jh= Cor1YD1[yr-1,2],r.kh= CorRecD1[1,2], n= CorRecD1[yr,6],
                                                                        alternative ="lower")@dunn1969[3]),4) # p value
  cor.rec.Y1.YrX.D1[i-1,7] <- round(Cor1YD1[yr-1,2]^2,3)
  cor.rec.Y1.YrX.D1[i-1,8] <- round(CorRecD1[yr,2]^2,3)
  cor.rec.Y1.YrX.D1[i-1,9] <- round((Cor1YD1[yr-1,2]^2) - (CorRecD1[yr,2]^2),3)
  cor.rec.Y1.YrX.D1[i-1,10] <- CorRecD1[yr,6]
  
  #D2
  cor.rec.Y1.YrX.D2[i-1,1] <- paste(i,"yr")
  cor.rec.Y1.YrX.D2[i-1,2] <- round(Cor1YD2[yr-1,2],3)
  cor.rec.Y1.YrX.D2[i-1,3] <- round(CorRecD2[yr,2],3)
  cor.rec.Y1.YrX.D2[i-1,4] <- round(Cor1YD2[yr-1,2] - CorRecD2[yr,2],3)
  cor.rec.Y1.YrX.D2[i-1,5] <- round(as.numeric(cocor.dep.groups.overlap(r.jk= CorRecD2[yr,2], r.jh= Cor1YD2[yr-1,2], r.kh= CorRecD2[1,2], n= CorRecD2[yr,6], 
                                                                        alternative ="lower")@dunn1969[2]),2) # Dunn & Clark test statistic
  cor.rec.Y1.YrX.D2[i-1,6] <- round(as.numeric(cocor.dep.groups.overlap(r.jk= CorRecD2[yr,2], r.jh= Cor1YD2[yr-1,2], r.kh= CorRecD2[1,2], n= CorRecD2[yr,6], 
                                                                        alternative ="lower")@dunn1969[3]),4) # p value
  cor.rec.Y1.YrX.D2[i-1,7] <- round(Cor1YD2[yr-1,2]^2,3)
  cor.rec.Y1.YrX.D2[i-1,8] <- round(CorRecD2[yr,2]^2,3)
  cor.rec.Y1.YrX.D2[i-1,9] <- round((Cor1YD2[yr-1,2]^2) - (CorRecD2[yr,2]^2),3)
  cor.rec.Y1.YrX.D2[i-1,10] <- CorRecD2[yr,6]
}


print(cor.rec.Y1.YrX.D2)# results in EDF4b for D2
print(cor.rec.Y1.YrX.D1)# results in EDF4b for D1

#### Other supplemental analyses and code 
# Relationship between SM and SWP
# Rainfall as predictor and relationship with soil moisture 
# Calculations of CNDD confidence intervals

# How representative is LUTZ SM data of SM in BCI FDP
## Comparison BCI-LUTZ WATERSHED SM ####
## EDF 5
#library(lubridate)
# Load and prepare Kupers BCI SM data
#from: https://springernature.figshare.com/collections/Dry_season_soil_water_potential_maps_of_a_50_hectare_tropical_forest_plot_on_Barro_Colorado_Island_Panama/4372898
BCI50ha.SM<-read.table(file=paste(sourcefiles4R,"BCI_Soil_moisture_mapping.txt",sep="/"), header=T, 
                       colClasses = c("NULL","numeric","numeric","numeric","character","NULL","character", "NULL","NULL","NULL","numeric","numeric","NULL")) 
BCI50ha.SM$date.ymd<-as.Date(BCI50ha.SM$date, format = "%m/%d/%Y")
BCI50ha.SM$year<-year(BCI50ha.SM$date.ymd)
BCI50ha.SM$month<-month(BCI50ha.SM$date.ymd)
BCI50ha.SM<-BCI50ha.SM[order(BCI50ha.SM$date.ymd),]
unique(BCI50ha.SM$period) # months sampled
head(BCI50ha.SM)

# Load and prepare Lutz weekly data
Lutz.week<-read.table(file=paste(sourcefiles4R,"bci_lutz_deep_gsm_man.csv",sep="/"), header=T, sep = ",", 
                      colClasses = c("character","NULL","integer","NULL","NULL","NULL","NULL","numeric","character","NULL"))
Lutz.week$date.ymd<-as.Date(Lutz.week$date, format = "%d/%m/%Y")
Lutz.week$year<-year(Lutz.week$date.ymd)
Lutz.week$month<-month(Lutz.week$date.ymd)
Lutz.week$swc<-as.numeric(Lutz.week$h2o_by_dry)
Lutz.week.period<-Lutz.week[Lutz.week$chk_note=="good" & ((year(Lutz.week$date.ymd)%in%c(2015) & month(Lutz.week$date.ymd)%in%c(02,03,04)) | (year(Lutz.week$date.ymd)%in%c(2016) & month(Lutz.week$date.ymd)%in%c(03))), 
                            c(-3)]# select sampling months as for LUTZ

# Sampling dates/month
# Feb 2015
unique(BCI50ha.SM[BCI50ha.SM$period=="feb.2015","date.ymd"])
unique(Lutz.week.period[Lutz.week.period$month==2 & Lutz.week.period$year==2015,"date.ymd"])
# Mar 2015
unique(BCI50ha.SM[BCI50ha.SM$period=="mar.2015","date.ymd"])
unique(Lutz.week.period[Lutz.week.period$month==3 & Lutz.week.period$year==2015,"date.ymd"])
# Apr 2015
unique(BCI50ha.SM[BCI50ha.SM$period=="apr.2015","date.ymd"])
unique(Lutz.week.period[Lutz.week.period$month==4 & Lutz.week.period$year==2015,"date.ymd"])
# Mar 2016
unique(BCI50ha.SM[BCI50ha.SM$period=="mar.2016","date.ymd"])
unique(Lutz.week.period[Lutz.week.period$month==3 & Lutz.week.period$year==2016,"date.ymd"])

# Group close dates together to maximize paired measurements. Groups are based on Lutz dates +/- 4 days avoiding overlap of BCI sampling dates among groups. 

Lutz.week.period$grp<- 
  ifelse(Lutz.week.period$date.ymd>="2015-02-20" & Lutz.week.period$date.ymd<="2015-02-23", 1,
    ifelse(Lutz.week.period$date.ymd>="2015-02-24" & Lutz.week.period$date.ymd<="2015-02-28", 2,
      ifelse(Lutz.week.period$date.ymd>="2015-03-20" & Lutz.week.period$date.ymd<="2015-03-24", 3,
        ifelse(Lutz.week.period$date.ymd>"2015-03-24" & Lutz.week.period$date.ymd<="2015-03-30", 4,
          ifelse(Lutz.week.period$date.ymd>"2015-03-30" & Lutz.week.period$date.ymd<="2015-04-07", 5,
            ifelse(Lutz.week.period$date.ymd>"2015-04-07" & Lutz.week.period$date.ymd<="2015-04-15", 6,
              ifelse(Lutz.week.period$date.ymd>="2016-03-11" & Lutz.week.period$date.ymd<="2016-03-14", 7,
                ifelse(Lutz.week.period$date.ymd>"2016-03-14" & Lutz.week.period$date.ymd<="2016-03-18", 8, NA
              )
            )
          )
        )
      )
    )
  )
)

BCI50ha.SM.n<-BCI50ha.SM[BCI50ha.SM$depth<45 & !is.na(BCI50ha.SM$depth),]# filter deep measurements

BCI50ha.SM.n$grp<- 
  ifelse(BCI50ha.SM.n$date.ymd>="2015-02-20" & BCI50ha.SM.n$date.ymd<="2015-02-23", 1,
    ifelse(BCI50ha.SM.n$date.ymd>="2015-02-24" & BCI50ha.SM.n$date.ymd<="2015-02-28", 2,
      ifelse(BCI50ha.SM.n$date.ymd>="2015-03-20" & BCI50ha.SM.n$date.ymd<="2015-03-24", 3,
        ifelse(BCI50ha.SM.n$date.ymd>"2015-03-24" & BCI50ha.SM.n$date.ymd<="2015-03-30", 4,
          ifelse(BCI50ha.SM.n$date.ymd>"2015-03-30" & BCI50ha.SM.n$date.ymd<="2015-04-07", 5,
            ifelse(BCI50ha.SM.n$date.ymd>"2015-04-07" & BCI50ha.SM.n$date.ymd<="2015-04-15", 6,
              ifelse(BCI50ha.SM.n$date.ymd>="2016-03-11" & BCI50ha.SM.n$date.ymd<="2016-03-14", 7,
                ifelse(BCI50ha.SM.n$date.ymd>"2016-03-14" & BCI50ha.SM.n$date.ymd<="2016-03-18", 8, NA
              )
            )
          )
        )
      )
    )
  )
)

# Period average
se <- function(x) sd(x) / sqrt(length(x))
#Lutz
Lutz.grp.avg<-summaryBy(swc~grp, id= ~month+year, FUN=c(mean,se, length), data=Lutz.week.period[!is.na(Lutz.week.period$grp),])
#BCI 50ha
BCI50ha.grp.avg<-summaryBy(swp~ grp, id= ~month+year, FUN=c(mean,se, length), data=BCI50ha.SM.n[!is.na(BCI50ha.SM.n$swp),])

# Correlation between Lutz SWC and BCI Soil Water Potential
cor.test(Lutz.grp.avg$swc.mean, BCI50ha.grp.avg$swp.mean)

# EDF 5 (includes calculation of CI)
windows(width=6.5, height=6)
plot(Lutz.grp.avg$swc.mean ,BCI50ha.grp.avg$swp.mean, xlab="Soil water content (%) at the monitored Lutz watershed", ylab="Soil water potential (MPa) at the 50-ha plot", pch=21, bg= "black",
     xlim=c(28,55), ylim=c(-0.62,-0.11))
clip(x1=29,x2=54.5,y1=-0.59,y2=-0.12)
x<-Lutz.grp.avg$swc.mean
y<-BCI50ha.grp.avg$swp.mean
lm.sw<-lm(y ~ x)
abline(lm.sw)
segments(y0=c(BCI50ha.grp.avg$swp.mean), x0= c(Lutz.grp.avg$swc.mean-Lutz.grp.avg$swc.se) , y1=c(BCI50ha.grp.avg$swp.mean), x1=c(Lutz.grp.avg$swc.mean+Lutz.grp.avg$swc.se), col='black', lwd=1,adj = 0)
segments(y0=c(BCI50ha.grp.avg$swp.mean-BCI50ha.grp.avg$swp.se), x0= c(Lutz.grp.avg$swc.mean) , y1=c(BCI50ha.grp.avg$swp.mean+BCI50ha.grp.avg$swp.se), x1=c(Lutz.grp.avg$swc.mean), col='black', lwd=1,adj = 0)
new.x = seq(29,54.5,by =0.05)
ci<- predict(lm.sw, newdata=data.frame(x=new.x), interval="confidence", level = 0.95)
lines(new.x, ci[,2], lty=2)
lines(new.x, ci[,3], lty=2)

# How good is rainfall as an explanatory variable? ####
# Wet season rainfall
RAINw_ZC<- glmer(ALIVE ~ CSD + HSD.fort + CLD + HLD + RAINw + CSD:RAINw + HSD.fort:RAINw + SpMO + SpMO:RAINw 
                 + (1+CSD + HSD.fort + CLD + HLD+ RAINw + HSD.fort:RAINw + CSD:RAINw||SPECIES)
                 + (1|PLOT) +(1|TRAP)
                 + (1 + CSD + HSD.fort + CLD + HLD + SpMO||YEAR),
                 control = glmerControl(optCtrl = list(maxfun = 1e+06)), data = Data,
                 family = binomial, verbose = 2, nAGQ = 1)
summary(RAINw_ZC)

# Dry season rainfall
RAINd_ZC<- glmer(ALIVE ~ CSD + HSD.fort + CLD + HLD + RAINd + CSD:RAINd + HSD.fort:RAINd + SpMO + SpMO:RAINd 
               + (1+CSD + HSD.fort + CLD + HLD+ RAINd + HSD.fort:RAINd + CSD:RAINd||SPECIES)
               + (1|PLOT) +(1|TRAP)
               + (1 + CSD + HSD.fort + CLD + HLD + SpMO||YEAR),
               control = glmerControl(optCtrl = list(maxfun = 1e+06)), data = Data,
               family = binomial, verbose = 2, nAGQ = 1)
summary(RAINd_ZC)

# Both seasons rainfall
RAINb_ZC<- glmer(ALIVE ~ CSD + HSD.fort + CLD + HLD + RAINb + CSD:RAINb + HSD.fort:RAINb + SpMO + SpMO:RAINb 
                 + (1+CSD + HSD.fort + CLD + HLD+ RAINb + HSD.fort:RAINb + CSD:RAINb||SPECIES)
                 + (1|PLOT) +(1|TRAP)
                 + (1 + CSD + HSD.fort + CLD + HLD + SpMO||YEAR),
                 control = glmerControl(optCtrl = list(maxfun = 1e+06)), data = Data,
                 family = binomial, verbose = 2, nAGQ = 1)
summary(RAINb_ZC)

# Delta AIC's with best (zero correlations) soil moisture model (SMw)
AIC(SMwzcT5)-AIC(RAINw_ZC)# ws
AIC(SMwzcT5)-AIC(RAINd_ZC)# ds
AIC(SMwzcT5)-AIC(RAINb_ZC)# bs

# How are Rainfall and SM correlated?
# CORRELATION BETWEEN MOISTURE & Rainfall 
# Monthly data
Rain_SM_Mo<-read.table(paste(sourcefiles4R,'/Monthly_summaries_pp_sm.txt',sep=""),
                       header=T,sep="\t",as.is=T)
# select all data with continuous records
noNA<-which(!(is.na(Rain_SM_Mo$RAIN)) & !(is.na(Rain_SM_Mo$SM)))# non NA
cont<-tapply(noNA, cumsum(c(1, diff(noNA)) != 1), range)# continuous records
Rain_SM_Mo<-Rain_SM_Mo[cont[[2]][1]:cont[[2]][2],]

# Test corelation
cor.test(Rain_SM_Mo$RAIN,Rain_SM_Mo$SM, method="spearman") # result in EDF1
#cor.test(Rain_SM_Mo$RAIN^0.25,Rain_SM_Mo$SM)# test with saturating relationship 

# CALCULATION OF CONFIDENCE INTERVALS for estimates of CNDD
# CI's of Figs 1 and 4a were calculated using the standard (Gls and Predict) functions of the 'rms' package
# CI's  of GLMM estimate of CNDD/year (Fig. 3a) are based on 10,000 simulations using the sim (arm package) function

#library(arm) # 
multi.fun <- function(x) {
  c(mean = mean(x), LCI = quantile(x, probs=c(0.025)), UCI = quantile(x, probs=c(0.975)))
}# calculates mean and quantiles
SMw<- unique(Data[order(Data$YEAR),c("SMw")])
BestModsim<-sim(bestmodel, n.sims = 10000) # the 'sim' function performs n.sims random draws of fixed and random effect coefficients of the glmer model

CNDDsim<-list()
for (i in 1:20){
  CNDDsim[[i]]<-BestModsim@fixef[,"CSD"] + BestModsim@ranef$YEAR[,i,"CSD"] + BestModsim@fixef[,"CSD:SMw"]*SMw[i]
}
CNDD.SM<-as.data.frame(matrix(unlist(lapply(CNDDsim, multi.fun)), nrow=20,ncol=3, byrow =T))
names(CNDD.SM)<-c("CNDD.y.mean", "CNDD.y.2.5%", "CNDD.y.97.5%")# mean and 95% CI of Fig. 3a
CNDD.SM$YEAR<-c(1996:2015)
CNDD.SM$SMw<-SMw

# CI of Figs 3c and d (changes in survival probability with soil moisture and low and high CSD)
xaxrnge<-(c(round(min(Div.all$SMw.raw)-.4),round(max(Div.all$SMw.raw)+.1))-median(Div.all$SMw.raw))/IQR(Div.all$SMw.raw)

# Low conspecific seedling density (LCSD)
srv.p.sim.LCSD<-list()
xseq<-seq(xaxrnge[1],xaxrnge[2],0.005)
for (i in 1:length(xseq)){
  srv.p.sim.LCSD[[i]]<-invlogit(BestModsim@fixef[,"(Intercept)"] +
                                  BestModsim@fixef[,"CSD"]*min(Data$CSD) +
                                  BestModsim@fixef[,"SMw"]* xseq[i] + BestModsim@fixef[,"CSD:SMw"]* xseq[i]* min(Data$CSD))}

srv.p.sts.LCSD<-as.data.frame(matrix(unlist(lapply(srv.p.sim.LCSD, multi.fun)), length(xseq),ncol=3, byrow =T))
names(srv.p.sts.LCSD)<-c("mean", "2.5%", "97.5%")# mean and 95% CI data of Fig. 3c

# High conspecific seedling density (HCSD)
srv.p.sim.HCSD<-list()
for (i in 1:length(xseq)){
  srv.p.sim.HCSD[[i]]<-invlogit(BestModsim@fixef[,"(Intercept)"] +
                                  BestModsim@fixef[,"CSD"]
                                * quantile(Data$CSD,probs = 0.845) 
                                + BestModsim@fixef[,"SMw"]* xseq[i] 
                                + BestModsim@fixef[,"CSD:SMw"]* xseq[i] 
                                * quantile(Data$CSD,probs = 0.845))}

srv.p.sts.HCSD<-as.data.frame(matrix(unlist(lapply(srv.p.sim.HCSD, multi.fun)), length(xseq),ncol=3, byrow =T))
names(srv.p.sts.HCSD)<-c("mean", "2.5%", "97.5%")# mean and 95% CI data of Fig. 3d

# END